'''title'''
__title__ = 'videofetch'
'''description'''
__description__ = 'Videodl: A lightweight video downloader written by pure python'
'''url'''
__url__ = 'https://github.com/CharlesPikachu/videodl'
'''version'''
__version__ = '0.1.4'
'''author'''
__author__ = 'Charles'
'''email'''
__email__ = 'charlesblwx@gmail.com'
'''license'''
__license__ = 'MIT License'
'''copyright'''
__copyright__ = 'Copyright 2021 Charles'